@@ -19,8 +19,8 @@
 #include <QtGui>
 #include <QMaemo5InformationBox>
 #include <iostream>
-
 #include "scoresheet.h"
+#include "csvfile.h"
 
 CScoresheet::CScoresheet(QWidget *win_)
 {
@@ -496,6 +496,115 @@ void CScoresheet::createSetup()
 	connect(stp_players, SIGNAL(valueChanged(int)), this, SLOT(playersNumChanged(int)));
 }
 
+void CScoresheet::save()
+{
+	dlg_file->setWindowTitle("Save file");
+	dlg_file->setFileMode(QFileDialog::AnyFile);
+	dlg_file->setAcceptMode(QFileDialog::AcceptSave);
+	
+	QStringList fileNames;
+	if( dlg_file->exec() )
+	{
+		fileNames = dlg_file->selectedFiles();
+
+		CCSVFile csv( fileNames.at(0) );
+		csv.appendRow(names);
+
+		QStringList row;		
+		for( int i=0; i<table->rowCount(); i++ )
+		{
+			row.clear();
+			for( int j=0; j<table->columnCount(); j++)
+			{
+				if( table->item(i,j) )
+					row.append( table->item(i,j)->text() );
+				else
+					row.append("");
+			}
+			csv.appendRow(row);
+		}
+		if( !csv.save() ) {
+			QMaemo5InformationBox::information ( win, "Could not open file for writing!",
+				QMaemo5InformationBox::DefaultTimeout );
+		} else {
+			QMaemo5InformationBox::information ( win, "Saved",
+				QMaemo5InformationBox::DefaultTimeout );
+		}
+	}
+}
+
+void CScoresheet::load()
+{
+	dlg_file->setWindowTitle("Load file");
+	dlg_file->setFileMode(QFileDialog::ExistingFile);
+	dlg_file->setAcceptMode(QFileDialog::AcceptOpen);
+	
+	QStringList fileNames;
+	if( dlg_file->exec() )
+	{
+		fileNames = dlg_file->selectedFiles();
+
+		CCSVFile csv( fileNames.at(0) );
+		
+		if( !csv.load() ) {
+			QMaemo5InformationBox::information ( win, "Could not load file!",
+				QMaemo5InformationBox::DefaultTimeout );
+			return;
+		}
+		sizeX = csv.columns();
+		sizeY = csv.rows()-1;  //first line is for headers
+		if( sizeX < minSizeX ) sizeX=minSizeX;
+		if( sizeX > maxSizeX ) sizeX=maxSizeX;
+		if( sizeY < minSizeY ) sizeY=minSizeY;
+		if( sizeY > maxSizeY ) sizeY=maxSizeY;
+		
+		names.clear();
+		table->clear();
+		for( int i=0; i<sizeX; i++ ) {
+			QString n = csv.dataAt(0,i);
+			QString s;
+			s.setNum(i+1);
+			if( n=="" ) n=defaultName+s;
+			names.append(n);
+		}
+		resizeTable();
+		loadingFile = true;
+
+		progress->setRange(0,sizeX*sizeY);
+		progress->setValue(0);
+		keys->hide();
+		barH->hide();
+		progress->show();
+		table->setEnabled(false);
+
+		for( int i=0; i<sizeX; i++ )
+		{
+			for(int j=0; j<sizeY; j++ )
+			{
+				QString t = csv.dataAt(j+1,i);
+				if( !table->item(j,i) && t.length()>0 )
+				{
+					QTableWidgetItem *item = new QTableWidgetItem();
+					table->setItem(j,i,item);
+					table->item(j,i)->setTextAlignment(Qt::AlignCenter);
+				}
+				if( t.length()>0 ) table->item(j,i)->setText(t);
+				progress->setValue(sizeX*j+i);
+			}
+		}
+
+   		progress->hide();
+   		if( !hideKeys ) keys->show();
+   		else if( portrait ) barH->show();
+		table->setEnabled(true);
+
+		loadingFile = false;		
+		updateHeaders();
+	}
+}
+
+
+/*
 void CScoresheet::save()
 {
 	dlg_file->setWindowTitle("Save file");
@@ -515,7 +624,7 @@ void CScoresheet::save()
 		}		
 		QTextStream out(&file);
 
-		out << sizeX << "," << sizeY << "\n";
+		//out << "ScoresheetSizeXY," << sizeX << "," << sizeY << "\n";
 		for( int i=0; i<names.count(); i++ )
 		{
 			QString s = names.at(i);
@@ -571,9 +680,15 @@ void CScoresheet::load()
 		}		
 		QTextStream in(&file);
 
+		bool sizeFound = false;
 		QString s = in.readLine();
-		sizeX = s.section(',',0,0).toInt();
-		sizeY = s.section(',',1,1).toInt();
+		if( s.section(',',0,0) == "ScoresheetSizeXY" ) {
+			sizeX = s.section(',',1,1).toInt();
+			sizeY = s.section(',',2,2).toInt();
+			sizeFound = true;
+		} else {
+			in.seek(0);
+		}
 		
 		if( sizeX < minSizeX || sizeX > maxSizeX )
 			sizeX = defaultSizeX;
@@ -586,24 +701,39 @@ void CScoresheet::load()
 		typing=false;
 		table->clear();
 		names.clear();
-		for(int i=0; i<sizeX; i++)
-		{
-			QString u;
-			u.setNum(i+1);
-			names << defaultName+u;
+		if( sizeFound ) {
+			for(int i=0; i<sizeX; i++)
+			{
+				QString u;
+				u.setNum(i+1);
+				names << defaultName+u;
+			}
 		}
-		resizeTable();
 
+		// does not work properly if names are not enclosed in ""
+		
 		s = in.readLine();
 		QStringList sl = s.split("\",\"");
 		int count = sl.count();
-		if (sizeX<count) count=sizeX;
+		if( !sizeFound ) {
+			if( count < minSizeX ) count = minSizeX;
+			if( count > maxSizeX ) count = maxSizeX;
+			for(int i=0; i<count; i++)
+			{
+				QString u;
+				u.setNum(i+1);
+				names << defaultName+u;
+			}
+		}
+		if (sizeFound && sizeX<count) count=sizeX;
 		for(int i=0; i<count; i++)
 		{
 			QString t = sl.at(i);
 			t.replace("\"","");
 			names[i] = t;
 		}
+		if( !sizeFound ) sizeX=names.count();
+		resizeTable();
 
 		progress->setRange(0,sizeX*sizeY);
 		progress->setValue(0);
@@ -612,6 +742,8 @@ void CScoresheet::load()
 		progress->show();
 		table->setEnabled(false);
 
+		//std::cout << "sizeX is " << sizeX << std::endl;
+
 		s = in.readLine();
 		int row=0;
      	while (!s.isNull()) {
@@ -643,8 +775,8 @@ void CScoresheet::load()
 
 		file.close();
 		loadingFile = false;
-		updateHeaders();		
+		updateHeaders();
 	}
 }
-
+*/
 
